@@ -442,7 +442,32 @@ set wafeHelp(XmTextFieldSetSelectionArray) { The procedure 'XmTextFieldSetSelect
 
 proc XmModifyVerifyCBset-type {} { return {function {void} {in: Boolean} {in: long} {in: long} {in: long} {in: String} ## {doit} {currInsert} {startPos} {endPos} {String}}}
 
-proc XmInstallImage-type {} { return {function {Boolean} {in: XtDisplay(Widget)} {in: String} {in: String} {const: False} {const: NULL} ## {widget to determine display} {filename or data} {short name}}}
+proc XmInstallImage-type {} { return {function {Boolean} {in: Widget} {in: String} {in: String} {const: False} {const: NULL} {const: 0} ## {widget to determine display and background color for shaped images} {filename or data} {short name}}}
+set wafeHelp(XmInstallImage) { The function 'XmInstallImage' install the image (2nd argument) with
+ the specified short name (3rd argument) for the display of the
+ Widget given in the first argument. The Image can be a name of a
+ .xbm file, the name of a .xpm file, or the content of an .xpm
+ file. If the function succeeds, it returns "1", otherwise "0".
+ 
+ The images are added to Motif's internal cache, which is used in
+ string to Pixmap or string to Bitmap conversions.
+ 
+ Xpm files are only supported, when Wafe was compiled with XPM
+ support.}
+
+proc XmUninstallImage-type {} { return {function {Boolean} {in: String} ## {image name}}}
+set wafeHelp(XmUninstallImage) { The function 'XmUninstallImage' removes the named image from the
+ image cache and returns "1" on success, "0" otherwise. 
+ 
+ When shaped images are added by the converter to the cache, it uses
+ as background color the widgets background color. If the same
+ shaped image is used on a widget with a different background, or
+ when the background color is changed, the image has to be removed
+ from the cache to obtain a different background color.
+
+ Note, that this flushing is only necessary, when shaped images are
+ used without shape masks. If the widget does not provide a shape
+ mask resource, use 'changePixmap' for shaping.}
 
 proc XmGetString-type {} { return {function {String} {in: Widget} {in: String} ## {widget} {resource name}}}
 set wafeHelp(XmGetString) { The function 'XmGetString' returns the value of the specified
