@@ -219,10 +219,6 @@ set wafeHelp(grabPointer) { The function 'grabPointer' establishes an active poi
  reference. In the latter case, the pointer is restricted to stay in
  the window of the specified widget.}
 
-proc heightOfScreen-type {} { return {function {int} {in: XtScreen(Widget)} ## {widget to determine screen}}}
-set wafeHelp(heightOfScreen) { The function 'heightOfScreen' returns the height of the screen (on
- which the specified widget is displayed) in pixels.}
-
 proc installAccelerators-type {} { return {function {void} {in: Widget} {in: Widget} ## {destination} {source}}}
 set wafeHelp(installAccelerators) { The command 'installAccelerators' merges the accelerator table from
  'source' (2nd argument) to 'destination' (1st argument).
@@ -459,7 +455,7 @@ set wafeHelp(unmapWidget) { The command 'unmapWidget' takes any number of widget
 
 proc unrealizeWidget-type {} { return {function {void} {callmultiple} {in: Widget} ## {widgets}}}
 set wafeHelp(unrealizeWidget) { The command 'unrealizeWidget' takes any number of widgets as arguments
- and unrelaizes them.}
+ and unrealizes them.}
 
 proc waitForVariable-type {} { return {function {String} {in: String} ## {variable name}}}
 set wafeHelp(waitForVariable) { The function 'waitForVariable' can be used to "wait" in a Tcl
@@ -478,10 +474,6 @@ proc widgetId-type {} { return {alias isWidget}}
 proc widgetName-type {} { return {function {Widget} {in: String} ## {widget reference}}}
 set wafeHelp(widgetName) { The function 'widgetName' returns the name of the specified widget.}
 
-proc widthOfScreen-type {} { return {function {int} {in: XtScreen(Widget)} ## {widget to determine screen}}}
-set wafeHelp(widthOfScreen) { The function 'widthOfScreen' returns the width of the screen on
- which the specified widget is displayed in pixels.}
-
 proc window-type {} { return {function {long} {in: Widget} ## {widget whose window you want}}}
 set wafeHelp(window) { The function 'window' returns the window id of the specified widget.}
 
@@ -617,3 +609,19 @@ set wafeHelp(getDomain) { The function 'getDomain' returns the domain (all possi
  Additionally the command 'showRes Widget' prints this information 
  on the screen.}
 
+proc screen-type {} { return {function {void} {in: String} {in: Widget} ## {sub command} {widget to determine display}}}
+set wafeHelp(screen) { The function 'screen' returns various information about the display
+ of the specified widget (2nd argument) depending on the specified
+ sub-command (1st argument). Valid sub commands are:
+ 
+    blackPixel    value of a black pixel
+    cells         max. number of color cells
+    height        height of screen
+    heightMM      height of screen in millimeters
+    name          name denoting screen (typically value of DISPLAY)
+    planes        number of planes
+    rootWindow    window id of root window 
+    whitePixel    value of a white pixel
+    width         width of screen
+    widthMM       width of screen in millimeters}
+
