@@ -1,10 +1,7 @@
+alias mDragIcon XmDragIcon
 alias mDropSiteManager XmDropSiteManager
 alias mDragContext XmDragContext
 alias mDropTransfer XmDropTransfer
 alias mDropSiteUnregister XmDropSiteUnregister
 alias mDropSiteStartUpdate XmDropSiteStartUpdate
 alias mDropSiteEndUpdate XmDropSiteEndUpdate
-alias mTextDisableRedisplay XmTextDisableRedisplay
-alias mTextFindString XmTextFindString
-alias mTextEnableRedisplay XmTextEnableRedisplay
-alias mScrollVisible XmScrollVisible
