@@ -6,4 +6,4 @@ alias mGraph XmGraph
 alias mGraphInsertRoots XmGraphInsertRoots
 alias mGraphDestroyAllArcs XmGraphDestroyAllArcs
 alias mGraphDestroyAllNodes XmGraphDestroyAllNodes
-alias mGraphRemoveArcBetweenNodes XmGraphRemoveArcBetweenNodes
+alias mGraphCenterAroundWidget XmGraphCenterAroundWidget
